/*
 *  GuiLoader, a GuiXml loader library
 *  Copyright (c) 2006 Maxim Udushlivy
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef GUILOADER_PROXIES_H
#define GUILOADER_PROXIES_H

#include "guiloader_impl.h"

void RegisterProxies(GuiLoaderInit * init);
void RegisterGType(GType type);

void GObjectProxy(Proxy * proxy);
void PropertyGObjectSignals(PropertyFuncData * data);

void GtkWidgetProxy(Proxy * proxy);
void GtkWidgetInit(GObject * object, Node * node);
void PropertyGtkWidgetSizeRequest(PropertyFuncData * data);
void PropertyGtkWidgetEvents(PropertyFuncData * data);
void GtkWidgetAddReceivesDefaultProperty(Proxy * proxy);
void GtkWidgetAddCanFocusProperty(Proxy * proxy);
void GtkWidgetAddCanDefaultProperty(Proxy * proxy);
void GtkWidgetAddAppPaintableProperty(Proxy * proxy);
void GtkWidgetAddEventProperties(Proxy * proxy);

void GtkContainerProxyBase(Proxy * proxy);

void GtkContainerProxy(Proxy * proxy);
void GtkContainerSetChildrenPropertyFunc(Proxy * proxy, PropertyFunc func);
void PropertyGtkContainerFocusChain(PropertyFuncData * data);
void PropertyGtkContainerFocusChild(PropertyFuncData * data);

void GideonChildProxy(Proxy * proxy);
void PropertyGideonChildWidget(PropertyFuncData * data);
void GideonChildAddIndexProperty(Proxy * proxy);
void PropertyGideonChildIndex(PropertyFuncData * data);

void GtkBinProxy(Proxy * proxy);
void PropertyGtkBinChildren(PropertyFuncData * data);

void GtkAlignmentProxy(Proxy * proxy);

void GtkFrameProxy(Proxy * proxy);
void PropertyGtkFrameLabelWidgetSet(PropertyFuncData * data);
void PropertyGtkFrameLabel(PropertyFuncData * data);

void GtkAspectFrameProxy(Proxy * proxy);
void GtkAspectFrameInit(GObject * object, Node * node);

void GtkExpanderProxy(Proxy * proxy);
void GtkExpanderInit(GObject * object, Node * node);
void PropertyGtkExpanderLabel(PropertyFuncData * data);

void GtkScrolledWindowProxy(Proxy * proxy);
void PropertyGtkScrolledWindowChildren(PropertyFuncData * data);
void PropertyGtkScrolledWindowAutoViewport(PropertyFuncData * data);

void GtkHandleBoxProxy(Proxy * proxy);
void GtkHandleBoxInit(GObject * object, Node * node);

void GtkViewportProxy(Proxy * proxy);

void GideonBoxChildProxy(Proxy * proxy);
void PropertyGideonBoxChildPack(PropertyFuncData * data);
void PropertyGideonBoxChildOptions(PropertyFuncData * data);
void PropertyGideonBoxChildPadding(PropertyFuncData * data);

void GtkBoxProxy(Proxy * proxy);
void PropertyGtkBoxChildren(PropertyFuncData * data);
void PropertyGtkBoxCapacity(PropertyFuncData * data);

void GideonButtonBoxChildProxy(Proxy * proxy);
void PropertyGideonButtonBoxChildSecondary(PropertyFuncData * data);

void GtkButtonBoxProxy(Proxy * proxy);
void PropertyGtkButtonBoxChildren(PropertyFuncData * data);
void PropertyGtkButtonBoxCapacity(PropertyFuncData * data);

void GideonPanedChildProxy(Proxy * proxy);
void PropertyGideonPanedChildResize(PropertyFuncData * data);
void PropertyGideonPanedChildShrink(PropertyFuncData * data);

void GtkPanedProxy(Proxy * proxy);
void PropertyGtkPanedChildren(PropertyFuncData * data);

void GideonNotebookChildProxy(Proxy * proxy);
void PropertyGideonNotebookChildTabLabel(PropertyFuncData * data);
void PropertyGideonNotebookChildTabLabelWidget(PropertyFuncData * data);
void PropertyGideonNotebookChildMenuLabel(PropertyFuncData * data);
void PropertyGideonNotebookChildMenuLabelWidget(PropertyFuncData * data);
void PropertyGideonNotebookChildPackOptions(PropertyFuncData * data);

void GtkNotebookProxy(Proxy * proxy);
void PropertyGtkNotebookChildren(PropertyFuncData * data);
void PropertyGtkNotebookCapacity(PropertyFuncData * data);

void GideonTableChildProxy(Proxy * proxy);
void PropertyGideonTableChildCell(PropertyFuncData * data);
void PropertyGideonTableChildCellSpan(PropertyFuncData * data);
void PropertyGideonTableChildPaddingX(PropertyFuncData * data);
void PropertyGideonTableChildPaddingY(PropertyFuncData * data);
void PropertyGideonTableChildXExpand(PropertyFuncData * data);
void PropertyGideonTableChildXFill(PropertyFuncData * data);
void PropertyGideonTableChildXShrink(PropertyFuncData * data);
void PropertyGideonTableChildYExpand(PropertyFuncData * data);
void PropertyGideonTableChildYFill(PropertyFuncData * data);
void PropertyGideonTableChildYShrink(PropertyFuncData * data);

void GtkTableProxy(Proxy * proxy);
GObject * GtkTableCreate(GuiLoader * loader, Node * node);
void PropertyGtkTableChildren(PropertyFuncData * data);
void PropertyGtkTableCapacity(PropertyFuncData * data);

void GideonXYChildProxy(Proxy * proxy);
void PropertyGideonXYChildXY(PropertyFuncData * data);

void GtkAdjustmentProxy(Proxy * proxy);

void GtkWindowProxy(Proxy * proxy);
GObject * GtkWindowCreate(GuiLoader * loader, Node * node);
gboolean GtkWindowOnDeleteEvent(GObject * window);
void PropertyGtkWindowDefaultSize(PropertyFuncData * data);
void PropertyGtkWindowAccelGroups(PropertyFuncData * data);
void PropertyGtkWindowTransientFor(PropertyFuncData * data);
void PropertyGtkWindowDefault(PropertyFuncData * data);

// GideonDialogButtonEntry -----------------------------------------------------

#define GIDEON_TYPE_DIALOG_BUTTON_ENTRY (gideon_dialog_button_entry_get_type())
#define GIDEON_DIALOG_BUTTON_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GIDEON_TYPE_DIALOG_BUTTON_ENTRY, GideonDialogButtonEntry))
#define GIDEON_IS_DIALOG_BUTTON_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), GIDEON_TYPE_DIALOG_BUTTON_ENTRY))

typedef struct _GideonDialogButtonEntry GideonDialogButtonEntry;

struct _GideonDialogButtonEntry {
	GObject parent;
	GtkWidget * widget;
	GtkResponseType response;
	gboolean secondary;
};

GType gideon_dialog_button_entry_get_type(void);
void gideon_dialog_button_entry_init(GideonDialogButtonEntry * entry);

// -----------------------------------------------------------------------------

void GideonDialogButtonEntryProxy(Proxy * proxy);
void PropertyGideonDialogButtonEntryWidget(PropertyFuncData * data);
void PropertyGideonDialogButtonEntryResponse(PropertyFuncData * data);
void PropertyGideonDialogButtonEntrySecondary(PropertyFuncData * data);

void GtkDialogProxy(Proxy * proxy);
void PropertyGtkDialogChildren(PropertyFuncData * data);
void PropertyGtkDialogButtons(PropertyFuncData * data);
void PropertyGtkDialogDefaultResponse(PropertyFuncData * data);

void GtkColorSelectionDialogProxy(Proxy * proxy);
void GtkColorSelectionDialogInit(GObject * object, Node * node);
void PropertyGtkColorSelectionDialogColorsel(PropertyFuncData * data);

void GtkFileFilterProxy(Proxy * proxy);
void PropertyGtkFileFilterName(PropertyFuncData * data);
void PropertyGtkFileFilterAddPixbufFormats(PropertyFuncData * data);
void PropertyGtkFileFilterPatterns(PropertyFuncData * data);
void PropertyGtkFileFilterMimeTypes(PropertyFuncData * data);

void GtkFileChooserProxyBase(Proxy * proxy);
void PropertyGtkFileChooserBaseFilter(PropertyFuncData * data);
void PropertyGtkFileChooserBaseFilters(PropertyFuncData * data);

void GtkFileChooserDialogProxy(Proxy * proxy);
GObject * GtkFileChooserDialogCreate(GuiLoader * loader, Node * node);

void GtkFontSelectionDialogProxy(Proxy * proxy);
void PropertyGtkFontSelectionDialogFontSelection(PropertyFuncData * data);

void GtkStatusbarProxy(Proxy * proxy);

// GideonTooltipsEntry ---------------------------------------------------------

#define GIDEON_TYPE_TOOLTIPS_ENTRY (gideon_tooltips_entry_get_type())
#define GIDEON_TOOLTIPS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GIDEON_TYPE_TOOLTIPS_ENTRY, GideonTooltipsEntry))
#define GIDEON_IS_TOOLTIPS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), GIDEON_TYPE_TOOLTIPS_ENTRY))

typedef struct _GideonTooltipsEntry GideonTooltipsEntry;

struct _GideonTooltipsEntry {
	GObject parent;
	GtkWidget * widget;
	const gchar * tip_text;
	const gchar * tip_private;
};

GType gideon_tooltips_entry_get_type(void);
void gideon_tooltips_entry_init(GideonTooltipsEntry * entry);

// -----------------------------------------------------------------------------

void GideonTooltipsEntryProxy(Proxy * proxy);
void PropertyGideonTooltipsEntryWidget(PropertyFuncData * data);
void PropertyGideonTooltipsEntryTipText(PropertyFuncData * data);
void PropertyGideonTooltipsEntryTipPrivate(PropertyFuncData * data);

void GtkTooltipsProxy(Proxy * proxy);
void PropertyGtkTooltipsEnabled(PropertyFuncData * data);
void PropertyGtkTooltipsTips(PropertyFuncData * data);

void GtkActionGroupProxy(Proxy * proxy);
GObject * GtkActionGroupCreate(GuiLoader * loader, Node * node);
void PropertyGtkActionGroupActions(PropertyFuncData * data);

void GtkActionProxy(Proxy * proxy);
GObject * GtkActionCreate(GuiLoader * loader, Node * node);
void PropertyGtkActionAccelerator(PropertyFuncData * data);

void GtkToggleActionProxy(Proxy * proxy);
GObject * GtkToggleActionCreate(GuiLoader * loader, Node * node);
void PropertyGtkToggleActionActive(PropertyFuncData * data);

void GtkRadioActionProxy(Proxy * proxy);
GObject * GtkRadioActionCreate(GuiLoader * loader, Node * node);
void PropertyGtkRadioActionGroup(PropertyFuncData * data);

void GtkUIManagerProxy(Proxy * proxy);
void PropertyGtkUIManagerActionGroups(PropertyFuncData * data);
void PropertyGtkUIManagerUiDefinitions(PropertyFuncData * data);

// GideonUIDefinition ----------------------------------------------------------

#define GIDEON_TYPE_UI_DEFINITION (gideon_ui_definition_get_type())
#define GIDEON_UI_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GIDEON_TYPE_UI_DEFINITION, GideonUIDefinition))
#define GIDEON_IS_UI_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), GIDEON_TYPE_UI_DEFINITION))

typedef struct _GideonUIDefinition GideonUIDefinition;

struct _GideonUIDefinition {
	GObject parent;
	const gchar * ui;
};

GType gideon_ui_definition_get_type(void);
void gideon_ui_definition_init(GideonUIDefinition * definition);

// -----------------------------------------------------------------------------

void GideonUIDefinitionProxy(Proxy * proxy);
void PropertyGideonUIDefinitionUi(PropertyFuncData * data);

void GideonUIElementProxy(Proxy * proxy);
GObject * GideonUIElementCreate(GuiLoader * loader, Node * node);

void GtkMenuBarProxy(Proxy * proxy);

void GtkToolbarProxy(Proxy * proxy);
void PropertyGtkToolbarToolbarStyleSet(PropertyFuncData * data);
void PropertyGtkToolbarTooltips(PropertyFuncData * data);

// GideonRadioGroup ------------------------------------------------------------

#define GIDEON_TYPE_RADIO_GROUP (gideon_radio_group_get_type())
#define GIDEON_RADIO_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), GIDEON_TYPE_RADIO_GROUP, GideonRadioGroup))
#define GIDEON_IS_RADIO_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), GIDEON_TYPE_RADIO_GROUP))

typedef struct _GideonRadioGroup GideonRadioGroup;

struct _GideonRadioGroup {
	GObject parent;
	GSList * list;
};

GType gideon_radio_group_get_type(void);
void gideon_radio_group_init(GideonRadioGroup * group);

// -----------------------------------------------------------------------------

void GideonRadioGroupProxy(Proxy * proxy);
void GtkMiscProxy(Proxy * proxy);

void GtkLabelProxy(Proxy * proxy);

void GtkButtonProxyBase(Proxy * proxy);

void GtkButtonProxy(Proxy * proxy);
void PropertyGtkButtonStockId(PropertyFuncData * data);

void GtkToggleButtonProxy(Proxy * proxy);

void GtkCheckButtonProxy(Proxy * proxy);

void GtkRadioButtonProxy(Proxy * proxy);
void PropertyGtkRadioButtonGroup(PropertyFuncData * data);

void GtkEntryCompletionProxy(Proxy * proxy);
void PropertyGtkEntryCompletionStrings(PropertyFuncData * data);

void GtkEntryProxy(Proxy * proxy);
void PropertyGtkEntryCompletion(PropertyFuncData * data);

void GtkComboBoxProxy(Proxy * proxy);
GObject * GtkComboBoxCreate(GuiLoader * loader, Node * node);
void PropertyGtkComboBoxStrings(PropertyFuncData * data);

void GtkComboBoxEntryProxy(Proxy * proxy);
GObject * GtkComboBoxEntryCreate(GuiLoader * loader, Node * node);
void PropertyGtkComboBoxEntryText(PropertyFuncData * data);
void PropertyGtkComboBoxEntryEntry(PropertyFuncData * data);

void GtkSpinButtonProxy(Proxy * proxy);

void GtkRangeProxy(Proxy * proxy);

void GtkScaleProxy(Proxy * proxy);

void GtkProgressBarProxy(Proxy * proxy);

void GtkImageProxy(Proxy * proxy);

void GtkSeparatorProxy(Proxy * proxy);

void GtkSizeGroupProxy(Proxy * proxy);
void PropertyGtkSizeGroupWidgets(PropertyFuncData * data);

void GtkTextViewProxy(Proxy * proxy);
void PropertyGtkTextViewText(PropertyFuncData * data);

void GtkIconViewProxy(Proxy * proxy);

void GtkCellViewProxy(Proxy * proxy);

void GtkTreeViewProxy(Proxy * proxy);
void PropertyGtkTreeViewSelectionMode(PropertyFuncData * data);

void GtkColorButtonProxy(Proxy * proxy);

void GtkColorSelectionProxy(Proxy * proxy);

void GtkFileChooserButtonProxy(Proxy * proxy);
GObject * GtkFileChooserButtonCreate(GuiLoader * loader, Node * node);

void GtkFileChooserWidgetProxy(Proxy * proxy);
GObject * GtkFileChooserWidgetCreate(GuiLoader * loader, Node * node);

void GtkFontButtonProxy(Proxy * proxy);

void GtkFontSelectionProxy(Proxy * proxy);

void GtkFixedProxy(Proxy * proxy);
void PropertyGtkFixedChildren(PropertyFuncData * data);

void GtkLayoutProxy(Proxy * proxy);
void PropertyGtkLayoutChildren(PropertyFuncData * data);
void PropertyGtkLayoutSize(PropertyFuncData * data);

void GtkScrollbarProxy(Proxy * proxy);

void GtkEventBoxProxy(Proxy * proxy);

void GtkDrawingAreaProxy(Proxy * proxy);

void GtkCalendarProxy(Proxy * proxy);

void GtkArrowProxy(Proxy * proxy);

#endif
